# OrzMC

A project for deploy minecraft client

Only support Python >=2.7, <4

# Support Minecraft Client Version

- support all version client version

- you should make sure the server version is the same as client version.

- This Program has been uploaded into PyPI

# Usage

You should have a jre runtime on you device

```
$ pip install orzmc
$ orzmc
```

The Game Content be saved under user's home directory, and named `.minecraft`


# Tips

这不是一个人的游戏，而是...           两个人😏